summaryrefslogtreecommitdiffstats
path: root/chrome/common
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common')
-rw-r--r--chrome/common/extensions/extension.cc11
-rw-r--r--chrome/common/extensions/extension_action.h4
-rw-r--r--chrome/common/render_messages_internal.h10
3 files changed, 5 insertions, 20 deletions
diff --git a/chrome/common/extensions/extension.cc b/chrome/common/extensions/extension.cc
index 1d34c97d..664b44a 100644
--- a/chrome/common/extensions/extension.cc
+++ b/chrome/common/extensions/extension.cc
@@ -367,14 +367,6 @@ ExtensionAction* Extension::LoadExtensionActionHelper(
return NULL;
}
result->set_popup_url(url);
-
- int height;
- if (!popup->GetInteger(keys::kPageActionPopupHeight, &height)) {
- *error = ExtensionErrorUtils::FormatErrorMessage(
- errors::kInvalidPageActionPopupHeight, "<missing>");
- return NULL;
- }
- result->set_popup_height(height);
} else if (!url_str.empty()) {
GURL url = GetResourceURL(url_str);
if (!url.is_valid()) {
@@ -383,9 +375,6 @@ ExtensionAction* Extension::LoadExtensionActionHelper(
return NULL;
}
result->set_popup_url(url);
- // TODO(erikkay): Need dynamic sizing of popups.
- // http://code.google.com/p/chromium/issues/detail?id=24471
- result->set_popup_height(100);
}
return result.release();
diff --git a/chrome/common/extensions/extension_action.h b/chrome/common/extensions/extension_action.h
index 2e34bbb..31fe0e7 100644
--- a/chrome/common/extensions/extension_action.h
+++ b/chrome/common/extensions/extension_action.h
@@ -52,9 +52,6 @@ class ExtensionAction {
const GURL& popup_url() const { return popup_url_; }
void set_popup_url(const GURL& url) { popup_url_ = url; }
- const int popup_height() const { return popup_height_; }
- void set_popup_height(int height) { popup_height_ = height; }
-
bool is_popup() const { return !popup_url_.is_empty(); }
private:
@@ -77,7 +74,6 @@ class ExtensionAction {
// If the action has a popup, it has a URL and a height.
GURL popup_url_;
- int popup_height_;
};
typedef std::map<std::string, ExtensionAction*> ExtensionActionMap;
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 7408ab8..ebff2dc 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -694,9 +694,8 @@ IPC_BEGIN_MESSAGES(View)
// the widget position while these asynchronous operations are in progress.
IPC_MESSAGE_ROUTED0(ViewMsg_Move_ACK)
- // Used to instruct the RenderView to send back updates to the intrinsic
- // width.
- IPC_MESSAGE_ROUTED0(ViewMsg_EnableIntrinsicWidthChangedMode)
+ // Used to instruct the RenderView to send back updates to the preferred size.
+ IPC_MESSAGE_ROUTED0(ViewMsg_EnablePreferredSizeChangedMode)
// Used to inform the renderer that the browser has displayed its
// requested notification.
@@ -1135,8 +1134,9 @@ IPC_BEGIN_MESSAGES(ViewHost)
GURL /* referrer */,
WindowOpenDisposition /* disposition */)
- IPC_MESSAGE_ROUTED1(ViewHostMsg_DidContentsPreferredWidthChange,
- int /* pref_width */)
+ // Notify that the preferred size of the content changed.
+ IPC_MESSAGE_ROUTED1(ViewHostMsg_DidContentsPreferredSizeChange,
+ gfx::Size /* pref_size */)
// Following message is used to communicate the values received by the
// callback binding the JS to Cpp.